@@ -19,7 +19,7 @@ from requests_oauthlib import OAuth2Session
 from . import utils
 from .dataset import Dataset
 from .exceptions import PipeAlreadyExists, SystemAlreadyExists, ConfigUploadFailed, \
-    TimeoutWhileWaitingForBackupToFinishException, ServiceUnavailable, InternalServerError
+    TimeoutWhileWaitingForBackupToFinishException, ServiceUnavailable, InternalServerError, BadRequestException
 from .log import Log
 from .pipe import Pipe
 from .system import System
@@ -244,7 +244,8 @@ class Connection:
                     utils.validate_response_is_ok(response, allowable_response_status_codes)
 
                 return response
-            except (RequestException, InternalServerError, ServiceUnavailable, ConnectionError) as e:
+            except (RequestException, ConnectionError,
+                    InternalServerError, ServiceUnavailable, BadRequestException) as e:
                 if retries <= 0:
                     raise e
 
@@ -278,7 +279,8 @@ class Connection:
                     utils.validate_response_is_ok(response, allowable_response_status_codes)
 
                 return response
-            except (RequestException, InternalServerError, ServiceUnavailable, ConnectionError) as e:
+            except (RequestException, ConnectionError,
+                    InternalServerError, ServiceUnavailable, BadRequestException) as e:
                 if retries <= 0:
                     raise e
 
@@ -310,7 +312,8 @@ class Connection:
                     utils.validate_response_is_ok(response, allowable_response_status_codes)
 
                 return response
-            except (RequestException, InternalServerError, ServiceUnavailable, ConnectionError) as e:
+            except (RequestException, ConnectionError,
+                    InternalServerError, ServiceUnavailable, BadRequestException) as e:
                 if retries <= 0:
                     raise e
 
@@ -343,7 +346,8 @@ class Connection:
                     utils.validate_response_is_ok(response, allowable_response_status_codes)
 
                 return response
-            except (RequestException, InternalServerError, ServiceUnavailable, ConnectionError) as e:
+            except (RequestException, ConnectionError,
+                    InternalServerError, ServiceUnavailable, BadRequestException) as e:
                 if retries <= 0:
                     raise e
 
@@ -377,7 +381,8 @@ class Connection:
                     utils.validate_response_is_ok(response, allowable_response_status_codes)
 
                 return response
-            except (RequestException, InternalServerError, ServiceUnavailable, ConnectionError) as e:
+            except (RequestException, ConnectionError,
+                    InternalServerError, ServiceUnavailable, BadRequestException) as e:
                 if retries <= 0:
                     raise e
 
@@ -415,7 +420,8 @@ class Connection:
                     utils.validate_response_is_ok(response, allowable_response_status_codes)
 
                 return response
-            except (RequestException, InternalServerError, ServiceUnavailable, ConnectionError) as e:
+            except (RequestException, ConnectionError,
+                    InternalServerError, ServiceUnavailable, BadRequestException) as e:
                 if retries <= 0:
                     raise e
 
