@@ -1,5 +1,6 @@
 # Copyright (C) Bouvet ASA - All Rights Reserved.
 # Unauthorized copying of this file, via any medium is strictly prohibited.
+import copy
 import time
 import json
 import logging
@@ -251,3 +252,7 @@ class Dataset(EntityBase):
                                                     data=postdata, **kwargs)
 
         return response.json()
+
+    @property
+    def runtime(self):
+        return copy.deepcopy(self._raw_jsondata["runtime"])
