@@ -134,6 +134,7 @@ class Pipe(EntityBase):
                       previous_request_id=None,
                       is_last=None,
                       is_first=None,
+                      completeness=None,
                       **kwargs
                       ):
         """This posts the specified entities to the pipe. This only works for pipes that has a source
@@ -168,9 +169,12 @@ class Pipe(EntityBase):
         if is_first is not None:
             params["is_first"] = is_first
 
+        headers = {"Content-Type": "application/json"}
+        if completeness is not None:
+            headers["X-Dataset-Completeness"] = str(completeness)
         response = self._connection.do_post_request(url,
                                                     allowable_response_status_codes=[200],
-                                                    headers={"Content-Type": "application/json"},
+                                                    headers=headers,
                                                     params=params,
                                                     data=entities_stream, **kwargs)
 
@@ -212,6 +216,9 @@ class Pipe(EntityBase):
                 time.sleep(1)
                 continue
 
+            runtime = self.runtime
+            if "state" not in self.runtime:
+                raise AssertionError(f"No 'state' property found in self.runtime! self.runtime: {runtime}")
             if self.runtime["state"] != "Deploying":
                 return
             elapsetime = time.monotonic() - starttime
